@@ -1,11 +1,12 @@
 package Crypt::SDTree::Publish;
 
+use 5.010000;
 use strict;
 use warnings;
 
 use Crypt::SDTree qw(:publish);
 
-our $VERSION = '0.03_02';
+our $VERSION = '0.01';
 
 sub new {
 	publish_new(@_);
@@ -21,6 +22,8 @@ Crypt::SDTree::Publish - Create Broadcast Messages
 
 =head1 SYNOPSIS
 
+  use 5.10.1;
+
   use Crypt::SDTree::Publish;
 
   # create a new publisher with all key maerial
