@@ -1,11 +1,12 @@
 package Crypt::SDTree::Subscribe;
 
+use 5.010000;
 use strict;
 use warnings;
 
 use Crypt::SDTree qw(:subscribe);
 
-our $VERSION = '0.03_02';
+our $VERSION = '0.01';
 
 sub new {
 	subscribe_new(@_);
@@ -21,6 +22,8 @@ Crypt::SDTree::Subscribe - Decrypt Broadcast Messages
 
 =head1 SYNOPSIS
 
+  use 5.10.1;
+
   use Crypt::SDTree::Subscribe;
 
   my $client = Crypt::SDTree::Subscribe->new('keyfile');
